==> haskell-crypto-random-0.0.9-30-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-crypto-random.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: crypto-random
version: 0.0.9
id: crypto-random-0.0.9-J75SZnAN3rZF55BWVYjD5q
key: crypto-random-0.0.9-J75SZnAN3rZF55BWVYjD5q
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
homepage: http://github.com/vincenthz/hs-crypto-random
synopsis: Simple cryptographic random related types
description:
    Simple cryptographic random related types
category: Cryptography
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
indefinite: False
exposed-modules:
    Crypto.Random Crypto.Random.API Crypto.Random.Test
hidden-modules: Crypto.Random.Generator Crypto.Random.Entropy
                Crypto.Random.Entropy.Source Crypto.Random.Entropy.Unix
abi: 777a113b860d634611fe57e199d73233
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/crypto-random-0.0.9
library-dirs: /usr/lib/ghc-8.2.2/site-local/crypto-random-0.0.9
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/crypto-random-0.0.9
hs-libraries: HScrypto-random-0.0.9-J75SZnAN3rZF55BWVYjD5q
depends:
    base-4.10.1.0 bytestring-0.10.8.2
    securemem-0.1.9-KrborjLaUmaBa3n2Ut05aK unix-2.7.2.2
    vector-0.12.0.1-IUGn3M9mkBh8CyXcBnfTR4
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             securemem-0.1.9-KrborjLaUmaBa3n2Ut05aK=bafd9851fe7e417e3885a49e80d7e0a4
             unix-2.7.2.2=3df01ca0d7640dab598065ff1b1cffeb
             vector-0.12.0.1-IUGn3M9mkBh8CyXcBnfTR4=d8375a46a4155c3f449ce3d319b3dbaa
haddock-interfaces: /usr/share/doc/haskell-crypto-random/html/crypto-random.haddock
haddock-html: /usr/share/doc/haskell-crypto-random/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-crypto-random-0.0.9-34-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-crypto-random.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: crypto-random
version: 0.0.9
id: crypto-random-0.0.9-6zv8g5mpIdp4uQzvtAIQnc
key: crypto-random-0.0.9-6zv8g5mpIdp4uQzvtAIQnc
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
homepage: http://github.com/vincenthz/hs-crypto-random
synopsis: Simple cryptographic random related types
description:
    Simple cryptographic random related types
category: Cryptography
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
indefinite: False
exposed-modules:
    Crypto.Random Crypto.Random.API Crypto.Random.Test
hidden-modules: Crypto.Random.Generator Crypto.Random.Entropy
                Crypto.Random.Entropy.Source Crypto.Random.Entropy.Unix
abi: 0020509381857db4e7795a97d0516a83
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/crypto-random-0.0.9
library-dirs: /usr/lib/ghc-8.2.2/site-local/crypto-random-0.0.9
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/crypto-random-0.0.9
hs-libraries: HScrypto-random-0.0.9-6zv8g5mpIdp4uQzvtAIQnc
depends:
    base-4.10.1.0 bytestring-0.10.8.2
    securemem-0.1.9-Hf5vOLwgobDWkNXRugKIW unix-2.7.2.2
    vector-0.12.0.1-IUGn3M9mkBh8CyXcBnfTR4
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             securemem-0.1.9-Hf5vOLwgobDWkNXRugKIW=56e2977764faba124f65ff95c568c569
             unix-2.7.2.2=3df01ca0d7640dab598065ff1b1cffeb
             vector-0.12.0.1-IUGn3M9mkBh8CyXcBnfTR4=d8375a46a4155c3f449ce3d319b3dbaa
haddock-interfaces: /usr/share/doc/haskell-crypto-random/html/crypto-random.haddock
haddock-html: /usr/share/doc/haskell-crypto-random/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
